@@ -38,7 +38,8 @@ from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.contentwarehouse_v1 import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -473,7 +474,7 @@ class DocumentSchemaServiceClient(metaclass=DocumentSchemaServiceClientMeta):
         parent: Optional[str] = None,
         document_schema: Optional[gcc_document_schema.DocumentSchema] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: Optional[float] = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> gcc_document_schema.DocumentSchema:
         r"""Creates a document schema.
@@ -589,7 +590,7 @@ class DocumentSchemaServiceClient(metaclass=DocumentSchemaServiceClientMeta):
         name: Optional[str] = None,
         document_schema: Optional[gcc_document_schema.DocumentSchema] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: Optional[float] = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> gcc_document_schema.DocumentSchema:
         r"""Updates a Document Schema. Returns INVALID_ARGUMENT if the name
@@ -713,7 +714,7 @@ class DocumentSchemaServiceClient(metaclass=DocumentSchemaServiceClientMeta):
         *,
         name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: Optional[float] = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> document_schema.DocumentSchema:
         r"""Gets a document schema. Returns NOT_FOUND if the document schema
@@ -818,7 +819,7 @@ class DocumentSchemaServiceClient(metaclass=DocumentSchemaServiceClientMeta):
         *,
         name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: Optional[float] = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes a document schema. Returns NOT_FOUND if the document
@@ -912,7 +913,7 @@ class DocumentSchemaServiceClient(metaclass=DocumentSchemaServiceClientMeta):
         *,
         parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: Optional[float] = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListDocumentSchemasPager:
         r"""Lists document schemas.
@@ -1036,14 +1037,9 @@ class DocumentSchemaServiceClient(metaclass=DocumentSchemaServiceClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-contentwarehouse",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("DocumentSchemaServiceClient",)
