@@ -38,7 +38,8 @@ from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.contentwarehouse_v1 import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -498,7 +499,7 @@ class DocumentServiceClient(metaclass=DocumentServiceClientMeta):
         parent: Optional[str] = None,
         document: Optional[gcc_document.Document] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: Optional[float] = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> document_service.CreateDocumentResponse:
         r"""Creates a document.
@@ -615,7 +616,7 @@ class DocumentServiceClient(metaclass=DocumentServiceClientMeta):
         *,
         name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: Optional[float] = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> gcc_document.Document:
         r"""Gets a document. Returns NOT_FOUND if the document does not
@@ -723,7 +724,7 @@ class DocumentServiceClient(metaclass=DocumentServiceClientMeta):
         name: Optional[str] = None,
         document: Optional[gcc_document.Document] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: Optional[float] = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> document_service.UpdateDocumentResponse:
         r"""Updates a document. Returns INVALID_ARGUMENT if the name of the
@@ -843,7 +844,7 @@ class DocumentServiceClient(metaclass=DocumentServiceClientMeta):
         *,
         name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: Optional[float] = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes a document. Returns NOT_FOUND if the document does not
@@ -938,7 +939,7 @@ class DocumentServiceClient(metaclass=DocumentServiceClientMeta):
         *,
         parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: Optional[float] = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.SearchDocumentsPager:
         r"""Searches for documents using provided
@@ -1057,7 +1058,7 @@ class DocumentServiceClient(metaclass=DocumentServiceClientMeta):
         *,
         resource: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: Optional[float] = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> document_service.FetchAclResponse:
         r"""Gets the access control policy for a resource. Returns NOT_FOUND
@@ -1164,7 +1165,7 @@ class DocumentServiceClient(metaclass=DocumentServiceClientMeta):
         resource: Optional[str] = None,
         policy: Optional[policy_pb2.Policy] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: Optional[float] = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> document_service.SetAclResponse:
         r"""Sets the access control policy for a resource.
@@ -1287,14 +1288,9 @@ class DocumentServiceClient(metaclass=DocumentServiceClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-contentwarehouse",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("DocumentServiceClient",)
