@@ -38,7 +38,8 @@ from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.contentwarehouse_v1 import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -471,7 +472,7 @@ class SynonymSetServiceClient(metaclass=SynonymSetServiceClientMeta):
         parent: Optional[str] = None,
         synonym_set: Optional[synonymset.SynonymSet] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: Optional[float] = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> synonymset.SynonymSet:
         r"""Creates a SynonymSet for a single context. Throws an
@@ -592,7 +593,7 @@ class SynonymSetServiceClient(metaclass=SynonymSetServiceClientMeta):
         *,
         name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: Optional[float] = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> synonymset.SynonymSet:
         r"""Gets a SynonymSet for a particular context. Throws a NOT_FOUND
@@ -705,7 +706,7 @@ class SynonymSetServiceClient(metaclass=SynonymSetServiceClientMeta):
         name: Optional[str] = None,
         synonym_set: Optional[synonymset.SynonymSet] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: Optional[float] = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> synonymset.SynonymSet:
         r"""Remove the existing SynonymSet for the context and replaces it
@@ -828,7 +829,7 @@ class SynonymSetServiceClient(metaclass=SynonymSetServiceClientMeta):
         *,
         name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: Optional[float] = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes a SynonymSet for a given context. Throws a NOT_FOUND
@@ -921,7 +922,7 @@ class SynonymSetServiceClient(metaclass=SynonymSetServiceClientMeta):
         *,
         parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: Optional[float] = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListSynonymSetsPager:
         r"""Returns all SynonymSets (for all contexts) for the
@@ -1046,14 +1047,9 @@ class SynonymSetServiceClient(metaclass=SynonymSetServiceClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-contentwarehouse",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("SynonymSetServiceClient",)
